@@ -47,7 +47,7 @@ class Base:
 
         # mongodb 에 연결
         if setting.active_mongo:
-            self.client = pymongo.MongoClient(setting.mongo_addr)
+            self.client = pymongo.MongoClient(setting.mongo_addr, serverSelectionTimeoutMS=5000)
             self.db = db
             self.col = col
             logger.info(f"__init__ set db : {self.db}\tcol : {self.col}")
@@ -82,13 +82,10 @@ class Base:
             setting 모듈을 통해 피클로 저장되는 세팅이 변하는 것이 아님
             전체 db 설정을 바꾸려면 setting.chg_mongo_addr()함수 사용할 것
         """
-        if not addr.startswith('mongodb://'):
-            raise ValueError(f'Invalid mongo address : {addr}')
-        else:
-            setting = load_setting()
-            logger.info(f'Set addr : {setting.mongo_addr} -> {addr}')
-            chg_mongo_addr(addr)
-            self.client = pymongo.MongoClient(addr)
+        setting = load_setting()
+        logger.info(f'Set addr : {setting.mongo_addr} -> {addr}')
+        chg_mongo_addr(addr)
+        self.client = pymongo.MongoClient(setting.mongo_addr, serverSelectionTimeoutMS=5000)
 
     # ======================상속 클래스에서 재구성할 수 있는 함수들================
     # get 관련함수는 self 를 사용하나 drop 관련 함수를 신중을 위해 self 를 사용하지 않고 반드시 인자로 받는다.
@@ -120,7 +117,7 @@ class Base:
         if db in pre_db:
             client.drop_database(db)
             post_db = Base.get_all_db()
-            print(f"Drop {db}..{len(pre_db)} -> {len(post_db)}")
+            print(f"Drop {db} db.. counting {len(pre_db)} -> {len(post_db)}")
         else:
             raise ValueError(f'Invalid value : {db}')
 
