@@ -551,6 +551,10 @@ class CRefresh(CEtc):
             {'항목': 'refresh'}, {"$set": {'count': self.COUNTER, 'date': date}}, upsert=True)
         return result.acknowledged
 
+    def get_date(self) -> str or None:
+        doc = self.client[self.code][self.page].find_one({'항목': 'refresh'})
+        return None if doc is None else doc['date']
+
     def count_down(self) -> bool:
         """
         데이터베이스의 카운트를 확인하고 0이하면 삭제 0 이상이면 1을 줄인다.
